@@ -4,24 +4,29 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "movedatafilesjob.h"
-#include <KIO/FileCopyJob>
+
 #include <QFileInfo>
 #include <QUrl>
+
+#include <KIO/FileCopyJob>
+#include <KIO/JobUiDelegate>
+#include <KJobTrackerInterface>
+#include <KLocalizedString>
+
 #include <interfaces/torrentfileinterface.h>
-#include <kio/jobuidelegate.h>
-#include <kjobtrackerinterface.h>
-#include <klocalizedstring.h>
 #include <util/fileops.h>
 #include <util/functions.h>
 #include <util/log.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 static ResourceManager move_data_files_slot(1);
 
 MoveDataFilesJob::MoveDataFilesJob()
     : Job(true, nullptr)
-    , Resource(&move_data_files_slot, "MoveDataFilesJob")
+    , Resource(&move_data_files_slot, u"MoveDataFilesJob"_s)
     , err(false)
     , active_job(nullptr)
     , running_recovery_jobs(0)
@@ -33,14 +38,14 @@ MoveDataFilesJob::MoveDataFilesJob()
 
 MoveDataFilesJob::MoveDataFilesJob(const QMap<TorrentFileInterface *, QString> &fmap)
     : Job(true, nullptr)
-    , Resource(&move_data_files_slot, "MoveDataFilesJob")
+    , Resource(&move_data_files_slot, u"MoveDataFilesJob"_s)
     , err(false)
     , active_job(nullptr)
     , running_recovery_jobs(0)
+    , file_map(fmap)
     , bytes_moved(0)
     , total_bytes(0)
     , bytes_moved_current_file(0)
-    , file_map(fmap)
 {
     QMap<TorrentFileInterface *, QString>::const_iterator i = file_map.constBegin();
     while (i != file_map.constEnd()) {
