@@ -29,6 +29,7 @@
 #include <version.h>
 
 using namespace net;
+using namespace Qt::Literals::StringLiterals;
 
 namespace bt
 {
@@ -80,21 +81,21 @@ UPnPService::UPnPService(const UPnPService &s)
 
 void UPnPService::setProperty(const QString &name, const QString &value)
 {
-    if (name == "serviceType")
+    if (name == "serviceType"_L1)
         servicetype = value;
-    else if (name == "controlURL")
+    else if (name == "controlURL"_L1)
         controlurl = value;
-    else if (name == "eventSubURL")
+    else if (name == "eventSubURL"_L1)
         eventsuburl = value;
-    else if (name == "SCPDURL")
+    else if (name == "SCPDURL"_L1)
         scpdurl = value;
-    else if (name == "serviceId")
+    else if (name == "serviceId"_L1)
         serviceid = value;
 }
 
 void UPnPService::clear()
 {
-    servicetype = controlurl = eventsuburl = scpdurl = serviceid = "";
+    servicetype = controlurl = eventsuburl = scpdurl = serviceid = QString();
 }
 
 UPnPService &UPnPService::operator=(const UPnPService &s)
@@ -111,15 +112,15 @@ UPnPService &UPnPService::operator=(const UPnPService &s)
 
 void UPnPDeviceDescription::setProperty(const QString &name, const QString &value)
 {
-    if (name == "friendlyName")
+    if (name == "friendlyName"_L1)
         friendlyName = value;
-    else if (name == "manufacturer")
+    else if (name == "manufacturer"_L1)
         manufacturer = value;
-    else if (name == "modelDescription")
+    else if (name == "modelDescription"_L1)
         modelDescription = value;
-    else if (name == "modelName")
+    else if (name == "modelName"_L1)
         modelName = value;
-    else if (name == "modelNumber")
+    else if (name == "modelNumber"_L1)
         modelNumber = value;
 }
 
@@ -141,11 +142,11 @@ void UPnPRouter::addService(UPnPService s)
         if (s.servicetype == os.servicetype)
             return;
     }
-    if (s.controlurl.startsWith("/")) {
-        s.controlurl = "http://" + d->location.host() + ":" + QString::number(d->location.port()) + s.controlurl;
+    if (s.controlurl.startsWith('/'_L1)) {
+        s.controlurl = "http://"_L1 + d->location.host() + ':'_L1 + QString::number(d->location.port()) + s.controlurl;
     }
-    if (s.eventsuburl.startsWith("/")) {
-        s.controlurl = "http://" + d->location.host() + ":" + QString::number(d->location.port()) + s.eventsuburl;
+    if (s.eventsuburl.startsWith('/'_L1)) {
+        s.controlurl = "http://"_L1 + d->location.host() + ':'_L1 + QString::number(d->location.port()) + s.eventsuburl;
     }
     d->services.append(s);
 }
@@ -190,7 +191,7 @@ void UPnPRouter::forward(const net::Port &port)
     Out(SYS_PNP | LOG_NOTICE) << "Forwarding port " << port.number << " (" << (port.proto == UDP ? "UDP" : "TCP") << ")" << endl;
     // first find the right service
     for (const UPnPService &s : std::as_const(d->services)) {
-        if (s.servicetype.contains("WANIPConnection") || s.servicetype.contains("WANPPPConnection")) {
+        if (s.servicetype.contains("WANIPConnection"_L1) || s.servicetype.contains("WANPPPConnection"_L1)) {
             d->forward(&s, port);
             found = true;
         }
@@ -248,7 +249,7 @@ void UPnPRouter::getExternalIPResult(HTTPRequest *r)
         if (!doc.setContent(r->replyData())) {
             Out(SYS_PNP | LOG_DEBUG) << "UPnP: GetExternalIP failed: invalid reply" << endl;
         } else {
-            QDomNodeList nodes = doc.elementsByTagName("NewExternalIPAddress");
+            QDomNodeList nodes = doc.elementsByTagName(u"NewExternalIPAddress"_s);
             if (nodes.count() > 0) {
                 d->external_ip = nodes.item(0).firstChild().nodeValue();
                 Out(SYS_PNP | LOG_DEBUG) << "UPnP: External IP: " << d->external_ip << endl;
@@ -387,43 +388,43 @@ void UPnPRouter::UPnPRouterPrivate::forward(const UPnPService *srv, const net::P
     // add all the arguments for the command
     QList<SOAP::Arg> args;
     SOAP::Arg a;
-    a.element = "NewRemoteHost";
+    a.element = u"NewRemoteHost"_s;
     args.append(a);
 
     // the external port
-    a.element = "NewExternalPort";
+    a.element = u"NewExternalPort"_s;
     a.value = QString::number(port.number);
     args.append(a);
 
     // the protocol
-    a.element = "NewProtocol";
-    a.value = port.proto == net::TCP ? "TCP" : "UDP";
+    a.element = u"NewProtocol"_s;
+    a.value = port.proto == net::TCP ? u"TCP"_s : u"UDP"_s;
     args.append(a);
 
     // the local port
-    a.element = "NewInternalPort";
+    a.element = u"NewInternalPort"_s;
     a.value = QString::number(port.number);
     args.append(a);
 
     // the local IP address
-    a.element = "NewInternalClient";
-    a.value = "$LOCAL_IP"; // will be replaced by our local ip in HTTPRequest
+    a.element = u"NewInternalClient"_s;
+    a.value = u"$LOCAL_IP"_s; // will be replaced by our local ip in HTTPRequest
     args.append(a);
 
-    a.element = "NewEnabled";
-    a.value = "1";
+    a.element = u"NewEnabled"_s;
+    a.value = u"1"_s;
     args.append(a);
 
-    a.element = "NewPortMappingDescription";
+    a.element = u"NewPortMappingDescription"_s;
     static Uint32 cnt = 0;
-    a.value = QString("KTorrent UPNP %1").arg(cnt++); // TODO: change this
+    a.value = u"KTorrent UPNP %1"_s.arg(cnt++); // TODO: change this
     args.append(a);
 
-    a.element = "NewLeaseDuration";
-    a.value = "0";
+    a.element = u"NewLeaseDuration"_s;
+    a.value = u"0"_s;
     args.append(a);
 
-    QString action = "AddPortMapping";
+    QString action = u"AddPortMapping"_s;
     QString comm = SOAP::createCommand(action, srv->servicetype, args);
 
     Forwarding fw = {port, nullptr, srv};
@@ -437,7 +438,7 @@ void UPnPRouter::UPnPRouterPrivate::forward(const UPnPService *srv, const net::P
             ++itr;
     }
 
-    fw.pending_req = sendSoapQuery(comm, srv->servicetype + "#" + action, srv->controlurl);
+    fw.pending_req = sendSoapQuery(comm, srv->servicetype + '#'_L1 + action, srv->controlurl);
     connect(fw.pending_req, &HTTPRequest::result, parent, &UPnPRouter::forwardResult);
     fwds.append(fw);
 }
@@ -447,22 +448,22 @@ void UPnPRouter::UPnPRouterPrivate::undoForward(const UPnPService *srv, const ne
     // add all the arguments for the command
     QList<SOAP::Arg> args;
     SOAP::Arg a;
-    a.element = "NewRemoteHost";
+    a.element = u"NewRemoteHost"_s;
     args.append(a);
 
     // the external port
-    a.element = "NewExternalPort";
+    a.element = u"NewExternalPort"_s;
     a.value = QString::number(port.number);
     args.append(a);
 
     // the protocol
-    a.element = "NewProtocol";
-    a.value = port.proto == net::TCP ? "TCP" : "UDP";
+    a.element = u"NewProtocol"_s;
+    a.value = port.proto == net::TCP ? u"TCP"_s : u"UDP"_s;
     args.append(a);
 
-    QString action = "DeletePortMapping";
+    QString action = u"DeletePortMapping"_s;
     QString comm = SOAP::createCommand(action, srv->servicetype, args);
-    HTTPRequest *r = sendSoapQuery(comm, srv->servicetype + "#" + action, srv->controlurl, waitjob != nullptr);
+    HTTPRequest *r = sendSoapQuery(comm, srv->servicetype + '#'_L1 + action, srv->controlurl, waitjob != nullptr);
 
     if (waitjob)
         waitjob->addExitOperation(r);
@@ -473,10 +474,10 @@ void UPnPRouter::UPnPRouterPrivate::undoForward(const UPnPService *srv, const ne
 void UPnPRouter::UPnPRouterPrivate::getExternalIP()
 {
     for (const UPnPService &s : std::as_const(services)) {
-        if (s.servicetype.contains("WANIPConnection") || s.servicetype.contains("WANPPPConnection")) {
-            QString action = "GetExternalIPAddress";
+        if (s.servicetype.contains("WANIPConnection"_L1) || s.servicetype.contains("WANPPPConnection"_L1)) {
+            QString action = u"GetExternalIPAddress"_s;
             QString comm = SOAP::createCommand(action, s.servicetype);
-            HTTPRequest *r = sendSoapQuery(comm, s.servicetype + "#" + action, s.controlurl);
+            HTTPRequest *r = sendSoapQuery(comm, s.servicetype + '#'_L1 + action, s.controlurl);
             connect(r, &HTTPRequest::result, parent, &UPnPRouter::getExternalIPResult);
             break;
         }
